@@ -90,7 +90,7 @@ def parse_time(string: str) -> Optional[mod_datetime.datetime]:
 
 def format_time(time: mod_datetime.datetime) -> str:
     offset = time.utcoffset()
-    if not offset or offset == 0:
+    if not offset:
         tz = 'Z'
     else:
         tz = time.strftime('%z')
@@ -166,11 +166,13 @@ class GPXField(AbstractGPXField):
         if tag and attribute:
             from . import gpx as mod_gpx
             raise mod_gpx.GPXException('Only tag *or* attribute may be given!')
+
+        self.tag: Optional[str] = None
         if attribute:
             self.tag = None
             self.attribute = attribute
         elif tag:
-            self.tag = name if tag is True else tag
+            self.tag = name if (tag is True) else tag # type: ignore
             self.attribute = None
         else:
             self.tag = name
@@ -603,9 +605,9 @@ def gpx_check_slots_and_default_values(classs: Callable[[], Any]) -> None:
     instance = classs()
 
     try:
-        attributes = list(filter(lambda x : x[0] != '_', dir(instance)))
-        attributes = list(filter(lambda x : not callable(getattr(instance, x)), attributes))
-        attributes = list(filter(lambda x : not x.startswith('gpx_'), attributes))
+        attributes = [x for x in dir(instance)
+                      if not x.startswith(('_', 'gpx_'))
+                      and not callable(getattr(instance, x))]
     except Exception as e:
         raise Exception(f'Error reading attributes for {classs.__name__}: {e}')
 
